@@ -104,7 +104,6 @@ class Translator:
             )
         return allele
 
-
     ############################################################################
     ## INTERNAL
 
@@ -140,14 +139,11 @@ class Translator:
         end = start + len(ref)
         ins_seq = alt
 
-        interval = models.SequenceInterval(start=models.Number(value=start, type="Number"),
-                                           end=models.Number(value=end, type="Number"),
-                                           type="SequenceInterval")
-        location = models.SequenceLocation(sequence_id=sequence_id,
-                                           interval=interval, type="SequenceLocation")
-        state = models.LiteralSequenceExpression(sequence=ins_seq,
-                                                  type="LiteralSequenceExpression")
-        allele = models.Allele(location=location, state=state, type="Allele")
+        interval = models.SequenceInterval(start=models.Number(value=start),
+                                           end=models.Number(value=end))
+        location = models.Location(sequence_id=sequence_id, interval=interval)
+        state = models.LiteralSequenceExpression(sequence=ins_seq)
+        allele = models.Allele(location=location, state=state)
         allele = self._post_process_imported_allele(allele)
         return allele
 
@@ -184,12 +180,11 @@ class Translator:
         end = start + len(ref)
         ins_seq = alt
 
-        interval = models.SequenceInterval(start=models.Number(value=start, type="Number"),
-                                           end=models.Number(value=end, type="Number"),
-                                           type="SequenceInterval")
-        location = models.SequenceLocation(sequence_id=sequence_id, interval=interval, type="SequenceLocation")
-        sstate = models.LiteralSequenceExpression(sequence=ins_seq, type="LiteralSequenceExpression")
-        allele = models.Allele(location=location, state=sstate, type="Allele")
+        interval = models.SequenceInterval(start=models.Number(value=start),
+                                           end=models.Number(value=end))
+        location = models.Location(sequence_id=sequence_id, interval=interval)
+        sstate = models.LiteralSequenceExpression(sequence=ins_seq)
+        allele = models.Allele(location=location, state=sstate)
         allele = self._post_process_imported_allele(allele)
         return allele
 
@@ -230,15 +225,13 @@ class Translator:
 
         if sv.posedit.edit.type == "ins":
             interval = models.SequenceInterval(
-                start=models.Number(value=sv.posedit.pos.start.base, type="Number"),
-                end=models.Number(value=sv.posedit.pos.start.base, type="Number"),
-                type="SequenceInterval")
+                start=models.Number(value=sv.posedit.pos.start.base),
+                end=models.Number(value=sv.posedit.pos.start.base))
             state = sv.posedit.edit.alt
         elif sv.posedit.edit.type in ("sub", "del", "delins", "identity"):
             interval = models.SequenceInterval(
-                start=models.Number(value=sv.posedit.pos.start.base - 1, type="Number"),
-                end=models.Number(value=sv.posedit.pos.end.base, type="Number"),
-                type="SequenceInterval")
+                start=models.Number(value=sv.posedit.pos.start.base - 1),
+                end=models.Number(value=sv.posedit.pos.end.base))
             if sv.posedit.edit.type == "identity":
                 state = self.data_proxy.get_sequence(sv.ac,
                                                      sv.posedit.pos.start.base - 1,
@@ -248,9 +241,8 @@ class Translator:
         elif sv.posedit.edit.type == "dup":
 
             interval = models.SequenceInterval(
-                start=models.Number(value=sv.posedit.pos.start.base - 1, type="Number"),
-                end=models.Number(value=sv.posedit.pos.end.base, type="Number"),
-                type="SequenceInterval")
+                start=models.Number(value=sv.posedit.pos.start.base - 1),
+                end=models.Number(value=sv.posedit.pos.end.base))
 
             ref = self.data_proxy.get_sequence(sv.ac,
                                                sv.posedit.pos.start.base - 1,
@@ -259,9 +251,9 @@ class Translator:
         else:
             raise ValueError(f"HGVS variant type {sv.posedit.edit.type} is unsupported")
 
-        location = models.SequenceLocation(sequence_id=sequence_id, interval=interval, type="SequenceLocation")
-        sstate = models.LiteralSequenceExpression(sequence=state, type="LiteralSequenceExpression")
-        allele = models.Allele(location=location, state=sstate, type="Allele", )
+        location = models.Location(sequence_id=sequence_id, interval=interval)
+        sstate = models.LiteralSequenceExpression(sequence=state)
+        allele = models.Allele(location=location, state=sstate)
         allele = self._post_process_imported_allele(allele)
         return allele
 
@@ -302,12 +294,11 @@ class Translator:
         end = start + del_len
         ins_seq = g["ins_seq"]
 
-        interval = models.SequenceInterval(start=models.Number(value=start, type="Number"),
-                                           end=models.Number(value=end, type="Number"),
-                                           type="SequenceInterval")
-        location = models.SequenceLocation(sequence_id=sequence_id, interval=interval, type="SequenceLocation")
-        sstate = models.LiteralSequenceExpression(sequence=ins_seq, type="LiteralSequenceExpression")
-        allele = models.Allele(location=location, state=sstate, type="Allele")
+        interval = models.SequenceInterval(start=models.Number(value=start),
+                                           end=models.Number(value=end))
+        location = models.Location(sequence_id=sequence_id, interval=interval)
+        sstate = models.LiteralSequenceExpression(sequence=ins_seq)
+        allele = models.Allele(location=location, state=sstate)
         allele = self._post_process_imported_allele(allele)
         return allele
 
@@ -361,8 +352,8 @@ class Translator:
                 return "g"
             return None
 
-        if not self.is_valid_allele(vo):
-            raise ValueError("_to_hgvs requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
+        if self.is_valid_allele(vo):
+            raise ValueError(f"_to_hgvs requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
 
         sequence_id = str(vo.location.sequence_id)
         aliases = self.data_proxy.translate_sequence_identifier(sequence_id, namespace)
@@ -429,7 +420,6 @@ class Translator:
 
         return list(set(hgvs_exprs))
 
-
     def _to_spdi(self, vo, namespace="refseq"):
         """generates a *list* of SPDI expressions for VRS Allele.
 
@@ -448,23 +438,23 @@ class Translator:
         is expected to be normalized per VRS spec.
 
         """
-        if not self.is_valid_allele(vo):
-            raise ValueError("_to_spdi requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
+
+        if self.is_valid_allele(vo):
+            raise ValueError(f"_to_spdi requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
 
         sequence_id = str(vo.location.sequence_id)
         aliases = self.data_proxy.translate_sequence_identifier(sequence_id, namespace)
         aliases = [a.split(":")[1] for a in aliases]
+
         start, end = vo.location.interval.start.value, vo.location.interval.end.value
         spdi_tail = f":{start}:{end-start}:{vo.state.sequence}"
         spdis = [a + spdi_tail for a in aliases]
         return spdis
 
-
     def is_valid_allele(self, vo):
-        return (vo.type == "Allele"
-                and vo.location.type == "SequenceLocation"
-                and vo.state.type == "LiteralSequenceExpression")
-
+        return (type(vo).__name__ != "Allele"
+                or type(vo.location).__name__ != "SequenceLocation"
+                or type(vo.state).__name__ != "LiteralSequenceExpression")
 
     @lazy_property
     def _hgvs_parser(self):
